@@ -17,13 +17,13 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -340,7 +340,7 @@ ModuleExport size_t RegisterSCTImage(void)
   entry->magick=(IsImageFormatHandler *) IsSCT;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Scitex HandShake");
-  entry->module=ConstantString("SCT");
+  entry->magick_module=ConstantString("SCT");
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
